from . import sampling

def append_image_geometry_z_slice(data_container_array, input_attribute_matrix = None, destination_attribute_matrix = None, check_resolution = None, observer = None) -> int:
  """Pythonic interface to AppendImageGeometryZSlice Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    input_attribute_matrix (DataArrayPath): Sets the "InputAttributeMatrix" filter property
    destination_attribute_matrix (DataArrayPath): Sets the "DestinationAttributeMatrix" filter property
    check_resolution (bool): Sets the "CheckResolution" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = sampling.AppendImageGeometryZSlice()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_attribute_matrix is not None:
    filter.InputAttributeMatrix = input_attribute_matrix
  if destination_attribute_matrix is not None:
    filter.DestinationAttributeMatrix = destination_attribute_matrix
  if check_resolution is not None:
    filter.CheckResolution = check_resolution
  filter.execute()
  return filter.ErrorCode

def resample_image_geom(data_container_array, new_data_container_path = None, cell_attribute_matrix_path = None, cell_feature_attribute_matrix_path = None, spacing = None, renumber_features = None, save_as_new_data_container = None, feature_ids_array_path = None, observer = None) -> int:
  """Pythonic interface to ResampleImageGeom Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    new_data_container_path (DataArrayPath): Sets the "NewDataContainerPath" filter property
    cell_attribute_matrix_path (DataArrayPath): Sets the "CellAttributeMatrixPath" filter property
    cell_feature_attribute_matrix_path (DataArrayPath): Sets the "CellFeatureAttributeMatrixPath" filter property
    spacing (FloatVec3Type): Sets the "Spacing" filter property
    renumber_features (bool): Sets the "RenumberFeatures" filter property
    save_as_new_data_container (bool): Sets the "SaveAsNewDataContainer" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = sampling.ResampleImageGeom()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if new_data_container_path is not None:
    filter.NewDataContainerPath = new_data_container_path
  if cell_attribute_matrix_path is not None:
    filter.CellAttributeMatrixPath = cell_attribute_matrix_path
  if cell_feature_attribute_matrix_path is not None:
    filter.CellFeatureAttributeMatrixPath = cell_feature_attribute_matrix_path
  if spacing is not None:
    filter.Spacing = spacing
  if renumber_features is not None:
    filter.RenumberFeatures = renumber_features
  if save_as_new_data_container is not None:
    filter.SaveAsNewDataContainer = save_as_new_data_container
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  filter.execute()
  return filter.ErrorCode

def crop_image_geometry(data_container_array, new_data_container_name = None, cell_attribute_matrix_path = None, cell_feature_attribute_matrix_path = None, x_min = None, y_min = None, z_min = None, x_max = None, y_max = None, z_max = None, renumber_features = None, save_as_new_data_container = None, update_origin = None, feature_ids_array_path = None, observer = None) -> int:
  """Pythonic interface to CropImageGeometry Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    new_data_container_name (DataArrayPath): Sets the "NewDataContainerName" filter property
    cell_attribute_matrix_path (DataArrayPath): Sets the "CellAttributeMatrixPath" filter property
    cell_feature_attribute_matrix_path (DataArrayPath): Sets the "CellFeatureAttributeMatrixPath" filter property
    x_min (int): Sets the "XMin" filter property
    y_min (int): Sets the "YMin" filter property
    z_min (int): Sets the "ZMin" filter property
    x_max (int): Sets the "XMax" filter property
    y_max (int): Sets the "YMax" filter property
    z_max (int): Sets the "ZMax" filter property
    renumber_features (bool): Sets the "RenumberFeatures" filter property
    save_as_new_data_container (bool): Sets the "SaveAsNewDataContainer" filter property
    update_origin (bool): Sets the "UpdateOrigin" filter property
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = sampling.CropImageGeometry()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if new_data_container_name is not None:
    filter.NewDataContainerName = new_data_container_name
  if cell_attribute_matrix_path is not None:
    filter.CellAttributeMatrixPath = cell_attribute_matrix_path
  if cell_feature_attribute_matrix_path is not None:
    filter.CellFeatureAttributeMatrixPath = cell_feature_attribute_matrix_path
  if x_min is not None:
    filter.XMin = x_min
  if y_min is not None:
    filter.YMin = y_min
  if z_min is not None:
    filter.ZMin = z_min
  if x_max is not None:
    filter.XMax = x_max
  if y_max is not None:
    filter.YMax = y_max
  if z_max is not None:
    filter.ZMax = z_max
  if renumber_features is not None:
    filter.RenumberFeatures = renumber_features
  if save_as_new_data_container is not None:
    filter.SaveAsNewDataContainer = save_as_new_data_container
  if update_origin is not None:
    filter.UpdateOrigin = update_origin
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  filter.execute()
  return filter.ErrorCode

def extract_flagged_features(data_container_array, feature_ids_array_path = None, flagged_features_array_path = None, observer = None) -> int:
  """Pythonic interface to ExtractFlaggedFeatures Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    feature_ids_array_path (DataArrayPath): Sets the "FeatureIdsArrayPath" filter property
    flagged_features_array_path (DataArrayPath): Sets the "FlaggedFeaturesArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = sampling.ExtractFlaggedFeatures()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if feature_ids_array_path is not None:
    filter.FeatureIdsArrayPath = feature_ids_array_path
  if flagged_features_array_path is not None:
    filter.FlaggedFeaturesArrayPath = flagged_features_array_path
  filter.execute()
  return filter.ErrorCode

def nearest_point_fuse_regular_grids(data_container_array, reference_cell_attribute_matrix_path = None, sampling_cell_attribute_matrix_path = None, observer = None) -> int:
  """Pythonic interface to NearestPointFuseRegularGrids Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    reference_cell_attribute_matrix_path (DataArrayPath): Sets the "ReferenceCellAttributeMatrixPath" filter property
    sampling_cell_attribute_matrix_path (DataArrayPath): Sets the "SamplingCellAttributeMatrixPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = sampling.NearestPointFuseRegularGrids()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if reference_cell_attribute_matrix_path is not None:
    filter.ReferenceCellAttributeMatrixPath = reference_cell_attribute_matrix_path
  if sampling_cell_attribute_matrix_path is not None:
    filter.SamplingCellAttributeMatrixPath = sampling_cell_attribute_matrix_path
  filter.execute()
  return filter.ErrorCode

def regularize_z_spacing(data_container_array, cell_attribute_matrix_path = None, input_file = None, new_z_res = None, observer = None) -> int:
  """Pythonic interface to RegularizeZSpacing Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    cell_attribute_matrix_path (DataArrayPath): Sets the "CellAttributeMatrixPath" filter property
    input_file (QString): Sets the "InputFile" filter property
    new_z_res (float): Sets the "NewZRes" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = sampling.RegularizeZSpacing()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if cell_attribute_matrix_path is not None:
    filter.CellAttributeMatrixPath = cell_attribute_matrix_path
  if input_file is not None:
    filter.InputFile = input_file
  if new_z_res is not None:
    filter.NewZRes = new_z_res
  filter.execute()
  return filter.ErrorCode

def warp_regular_grid(data_container_array, new_data_container_name = None, cell_attribute_matrix_path = None, poly_order = None, second_order_a_coeff = None, second_order_b_coeff = None, third_order_a_coeff = None, third_order_b_coeff = None, fourth_order_a_coeff = None, fourth_order_b_coeff = None, save_as_new_data_container = None, observer = None) -> int:
  """Pythonic interface to WarpRegularGrid Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    new_data_container_name (DataArrayPath): Sets the "NewDataContainerName" filter property
    cell_attribute_matrix_path (DataArrayPath): Sets the "CellAttributeMatrixPath" filter property
    poly_order (int): Sets the "PolyOrder" filter property
    second_order_a_coeff (Float2ndOrderPolynomial): Sets the "SecondOrderACoeff" filter property
    second_order_b_coeff (Float2ndOrderPolynomial): Sets the "SecondOrderBCoeff" filter property
    third_order_a_coeff (Float3rdOrderPoly_t): Sets the "ThirdOrderACoeff" filter property
    third_order_b_coeff (Float3rdOrderPoly_t): Sets the "ThirdOrderBCoeff" filter property
    fourth_order_a_coeff (Float4thOrderPolynomial): Sets the "FourthOrderACoeff" filter property
    fourth_order_b_coeff (Float4thOrderPolynomial): Sets the "FourthOrderBCoeff" filter property
    save_as_new_data_container (bool): Sets the "SaveAsNewDataContainer" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = sampling.WarpRegularGrid()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if new_data_container_name is not None:
    filter.NewDataContainerName = new_data_container_name
  if cell_attribute_matrix_path is not None:
    filter.CellAttributeMatrixPath = cell_attribute_matrix_path
  if poly_order is not None:
    filter.PolyOrder = poly_order
  if second_order_a_coeff is not None:
    filter.SecondOrderACoeff = second_order_a_coeff
  if second_order_b_coeff is not None:
    filter.SecondOrderBCoeff = second_order_b_coeff
  if third_order_a_coeff is not None:
    filter.ThirdOrderACoeff = third_order_a_coeff
  if third_order_b_coeff is not None:
    filter.ThirdOrderBCoeff = third_order_b_coeff
  if fourth_order_a_coeff is not None:
    filter.FourthOrderACoeff = fourth_order_a_coeff
  if fourth_order_b_coeff is not None:
    filter.FourthOrderBCoeff = fourth_order_b_coeff
  if save_as_new_data_container is not None:
    filter.SaveAsNewDataContainer = save_as_new_data_container
  filter.execute()
  return filter.ErrorCode

def resample_rect_grid_to_image_geom(data_container_array, rectilinear_grid_path = None, rect_grid_geometry_desc = None, selected_data_array_paths = None, image_geometry_path = None, image_geom_cell_attribute_matrix = None, length_unit = None, dimensions = None, observer = None) -> int:
  """Pythonic interface to ResampleRectGridToImageGeom Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    rectilinear_grid_path (DataArrayPath): Sets the "RectilinearGridPath" filter property
    rect_grid_geometry_desc (QString): Sets the "RectGridGeometryDesc" filter property
    selected_data_array_paths (std::vector<DataArrayPath>): Sets the "SelectedDataArrayPaths" filter property
    image_geometry_path (DataArrayPath): Sets the "ImageGeometryPath" filter property
    image_geom_cell_attribute_matrix (QString): Sets the "ImageGeomCellAttributeMatrix" filter property
    length_unit (int32_t): Sets the "LengthUnit" filter property
    dimensions (IntVec3Type): Sets the "Dimensions" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = sampling.ResampleRectGridToImageGeom()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if rectilinear_grid_path is not None:
    filter.RectilinearGridPath = rectilinear_grid_path
  if rect_grid_geometry_desc is not None:
    filter.RectGridGeometryDesc = rect_grid_geometry_desc
  if selected_data_array_paths is not None:
    filter.SelectedDataArrayPaths = selected_data_array_paths
  if image_geometry_path is not None:
    filter.ImageGeometryPath = image_geometry_path
  if image_geom_cell_attribute_matrix is not None:
    filter.ImageGeomCellAttributeMatrix = image_geom_cell_attribute_matrix
  if length_unit is not None:
    filter.LengthUnit = length_unit
  if dimensions is not None:
    filter.Dimensions = dimensions
  filter.execute()
  return filter.ErrorCode

def sample_surface_mesh(data_container_array, surface_mesh_face_labels_array_path = None, observer = None) -> int:
  """Pythonic interface to SampleSurfaceMesh Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    surface_mesh_face_labels_array_path (DataArrayPath): Sets the "SurfaceMeshFaceLabelsArrayPath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = sampling.SampleSurfaceMesh()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if surface_mesh_face_labels_array_path is not None:
    filter.SurfaceMeshFaceLabelsArrayPath = surface_mesh_face_labels_array_path
  filter.execute()
  return filter.ErrorCode

def regular_grid_sample_surface_mesh(data_container_array, data_container_name = None, cell_attribute_matrix_name = None, length_unit = None, dimensions = None, spacing = None, origin = None, feature_ids_array_name = None, observer = None) -> int:
  """Pythonic interface to RegularGridSampleSurfaceMesh Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    length_unit (int32_t): Sets the "LengthUnit" filter property
    dimensions (IntVec3Type): Sets the "Dimensions" filter property
    spacing (FloatVec3Type): Sets the "Spacing" filter property
    origin (FloatVec3Type): Sets the "Origin" filter property
    feature_ids_array_name (QString): Sets the "FeatureIdsArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = sampling.RegularGridSampleSurfaceMesh()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if length_unit is not None:
    filter.LengthUnit = length_unit
  if dimensions is not None:
    filter.Dimensions = dimensions
  if spacing is not None:
    filter.Spacing = spacing
  if origin is not None:
    filter.Origin = origin
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  filter.execute()
  return filter.ErrorCode

def sample_surface_mesh_specified_points(data_container_array, input_file_path = None, output_file_path = None, observer = None) -> int:
  """Pythonic interface to SampleSurfaceMeshSpecifiedPoints Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    input_file_path (QString): Sets the "InputFilePath" filter property
    output_file_path (QString): Sets the "OutputFilePath" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = sampling.SampleSurfaceMeshSpecifiedPoints()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if input_file_path is not None:
    filter.InputFilePath = input_file_path
  if output_file_path is not None:
    filter.OutputFilePath = output_file_path
  filter.execute()
  return filter.ErrorCode

def uncertain_regular_grid_sample_surface_mesh(data_container_array, data_container_name = None, cell_attribute_matrix_name = None, x_points = None, y_points = None, z_points = None, spacing = None, origin = None, uncertainty = None, feature_ids_array_name = None, observer = None) -> int:
  """Pythonic interface to UncertainRegularGridSampleSurfaceMesh Filter which will execute the filter immediately and return.
  
  Args:
    data_container_array (DataContainerArray): The DataContainerArray that will be used as input
    data_container_name (DataArrayPath): Sets the "DataContainerName" filter property
    cell_attribute_matrix_name (QString): Sets the "CellAttributeMatrixName" filter property
    x_points (int): Sets the "XPoints" filter property
    y_points (int): Sets the "YPoints" filter property
    z_points (int): Sets the "ZPoints" filter property
    spacing (FloatVec3Type): Sets the "Spacing" filter property
    origin (FloatVec3Type): Sets the "Origin" filter property
    uncertainty (FloatVec3Type): Sets the "Uncertainty" filter property
    feature_ids_array_name (QString): Sets the "FeatureIdsArrayName" filter property
    observer (Observer): The observer that can report back warnings/errors.

  Returns:
    int
  """

  filter = sampling.UncertainRegularGridSampleSurfaceMesh()
  filter.setDataContainerArray(data_container_array)
  if observer is not None:
    filter.connectObserver(observer)
  if data_container_name is not None:
    filter.DataContainerName = data_container_name
  if cell_attribute_matrix_name is not None:
    filter.CellAttributeMatrixName = cell_attribute_matrix_name
  if x_points is not None:
    filter.XPoints = x_points
  if y_points is not None:
    filter.YPoints = y_points
  if z_points is not None:
    filter.ZPoints = z_points
  if spacing is not None:
    filter.Spacing = spacing
  if origin is not None:
    filter.Origin = origin
  if uncertainty is not None:
    filter.Uncertainty = uncertainty
  if feature_ids_array_name is not None:
    filter.FeatureIdsArrayName = feature_ids_array_name
  filter.execute()
  return filter.ErrorCode

